<?php

/**
 * Register password migrator Part II
 *
 * @version     1.1
 * @copyright   (c) 2012, Christoph M. Becker
 * @license     http://www.gnu.org/licenses/gpl.html  GPLv3
 */


/**
 * Returns the logged new passwords.
 *
 * @return array  user=>password
 */
function Register_passwords()
{
    global $pth, $plugin_tx;
    
    $fn = $pth['folder']['base'] . $plugin_tx['register']['config_usersfile'] . '.mig';
    $passes = array();
    $lines = file($fn);
    foreach ($lines as $line) {
        $line = rtrim($line);
        $rec = explode("\t", $line);
        $passes[$rec[0]] = $rec[1];
    }
    return $passes;
}


/**
 * Returns the list of users.
 *
 * @return array
 */
function Register_users()
{
    global $pth, $plugin_tx;
    
    $fn = $pth['folder']['base'] . $plugin_tx['register']['config_usersfile'];
    $users = array();
    $lines = file($fn);
    foreach ($lines as $line) {
        $line = rtrim($line);
        if (!empty($line) && strpos($line, '//') !== 0) {
            $rec = explode(':', $line);
            $users[] = $rec;
        }        
    }
    return $users;
}


/**
 * Saves the new users after making a backup of the old user's file.
 *
 * Returns whether that succeeded.
 *
 * @return bool
 */
function Register_saveUsers($users)
{
    global $pth, $plugin_tx;
    
    $fn = $pth['folder']['base'] . $plugin_tx['register']['config_usersfile'];
    if (file_exists($fn . '.bak')) {
        unlink($fn . '.bak');
    }
    if (!copy($fn, $fn . '.bak')) {
        e('cntsave', 'backup', $fn . '.bak');
        return false;
    }
    $lines = array('// Register Plugin user Definitions',
                   '// Line Format:',
                   '// login:password:accessgroup1,accessgroup2,...:fullname:email:status');
    foreach ($users as $user) {
        $lines[] = implode(':', $user);
    }
    $ok = ($fh = fopen($fn, 'wb')) !== false
        && fwrite($fh, implode("\n", $lines) . "\n") !== false;
    if ($fh !== false) {
        fclose($fh);
    }
    if (!$ok) {
        e('cntsave', 'file', $fn);
    }
    return $ok;
}


/**
 * Converts the passwords in the user's file.
 *
 * @return string  The success message as (X)HTML.
 */
function Register_convertPasswords()
{
    global $pth, $sl, $e, $plugin_tx;
    
    include $pth['folder']['plugins'] . 'register/languages/' . $sl . '.php';
    $users = Register_users();
    $passes = Register_passwords();
    $newUsers = array();
    $count = 0;
    foreach ($users as $user) {
        if (array_key_exists($user[0], $passes)) {
            $user[1] = $passes[$user[0]];
            $count++;
        }
        $newUsers[] = $user;
    }
    if (Register_saveUsers($newUsers)) {
        return '<div class="cmsimplecore_warning">Successfully converted '
            . $count . ' of ' . count($newUsers) . ' passwords</div>';
    } else {
        return '<div class="cmsimplecore_warning">Conversion not possible!</div>';
    }
}


/*
 * Handle the conversion.
 */
if ($adm && $function == 'registerconvertpasswords') {
    $o .= Register_convertPasswords();
}